@@ -9,7 +9,7 @@
 #' Selections of nodes can be performed using
 #' the following \code{select_...} functions:
 #' \code{select_nodes()},
-#' \code{select_last_node()},
+#' \code{select_last_nodes_created()},
 #' \code{select_nodes_by_degree()},
 #' \code{select_nodes_by_id()}, or
 #' \code{select_nodes_in_neighborhood()}.
@@ -23,6 +23,7 @@
 #' \code{dgr_graph}.
 #' @param node_attr the node attribute from which to
 #' obtain values.
+#' @param name an optional name for the cached vector.
 #' @param mode a option to recast the returned vector
 #' of node attribute value as \code{numeric} or
 #' \code{character}.
@@ -34,18 +35,21 @@
 #' # Create a graph with 6 nodes and 5 edges
 #' graph <-
 #'   create_graph() %>%
-#'   add_path(6) %>%
+#'   add_path(n = 6) %>%
 #'   set_node_attrs(
-#'     "value", rnorm(node_count(.), 5, 2))
+#'     node_attr = value,
+#'     values = rnorm(node_count(.), 5, 2))
 #'
-#' # Select all nodes where the node attribute `value`
-#' # is less than 5
+#' # Select all nodes where the node
+#' # attribute `value` is less than 5
 #' graph <-
 #'   graph %>%
-#'   select_nodes("value < 5.0")
+#'   select_nodes(
+#'     conditions = value < 5.0)
 #'
 #' # Show the graph's node data frame
-#' graph %>% get_node_df
+#' graph %>%
+#'   get_node_df()
 #' #>   id type label    value
 #' #> 1  1 <NA>     1 5.090874
 #' #> 2  2 <NA>     2 8.151559
@@ -55,26 +59,33 @@
 #' #> 6  6 <NA>     6 5.963101
 #'
 #' # Cache available values from the node attribute
-#' # `value` from the nodes that are selected; ensure
-#' # that the cached vector is numeric
+#' # `value` from the nodes that are selected;
+#' # ensure that the cached vector is numeric
 #' graph <-
 #'   graph %>%
-#'   cache_node_attrs_ws("value", "numeric")
+#'   cache_node_attrs_ws(
+#'     node_attr = value,
+#'     name = "node_value")
 #'
-#' # Get the cached vector and get its
-#' # difference from 5
-#' graph %>% get_cache() %>% {x <- .; 5 - x}
-#' #> [1] 2.0930707 0.5773773
+#' # Get the cached vector with `get_cache()`
+#' graph %>%
+#'   get_cache(name = "node_value")
+#' #> [1] 2.906929 4.422623
 #' @importFrom dplyr filter select_ rename_ mutate
+#' @importFrom rlang enquo UQ
 #' @export cache_node_attrs_ws
 
 cache_node_attrs_ws <- function(graph,
                                 node_attr,
+                                name = NULL,
                                 mode = NULL) {
 
   # Get the time of function start
   time_function_start <- Sys.time()
 
+  node_attr <- rlang::enquo(node_attr)
+  node_attr <- (rlang::UQ(node_attr) %>% paste())[2]
+
   # Validation: Graph object is valid
   if (graph_object_valid(graph) == FALSE) {
     stop("The graph object is not valid.")
@@ -123,8 +134,19 @@ cache_node_attrs_ws <- function(graph,
     }
   }
 
-  # Cache vector of node attributes in the graph
-  graph$cache <- nodes_cache[,1]
+  # Cache vector of edge attributes in the
+  # graph's `cache` list object
+  if (!is.null(name)) {
+    graph$cache[[name]] <- nodes_cache[, 1]
+  } else {
+    if (length(graph$cache) == 0) {
+      graph$cache[[1]] <- nodes_cache[, 1]
+      names(graph$cache) <- 1
+    } else {
+      graph$cache[[(length(graph$cache) + 1)]] <-
+        nodes_cache[, 1]
+    }
+  }
 
   # Update the `graph_log` df with an action
   graph$graph_log <-
@@ -142,5 +164,5 @@ cache_node_attrs_ws <- function(graph,
     save_graph_as_rds(graph = graph)
   }
 
-  return(graph)
+  graph
 }
