@@ -5,25 +5,31 @@
 #' \code{dgr_graph}.
 #' @return a vector of node IDs.
 #' @examples
-#' # Create a random graph
+#' # Create a random graph and make every node
+#' # shape a `square`
 #' graph <-
 #'   create_random_graph(
-#'     30, 50, set_seed = 1) %>%
-#'   set_node_attrs("shape", "square")
+#'     n = 30, m = 50,
+#'     set_seed = 23) %>%
+#'   set_node_attrs(
+#'     node_attr = "shape",
+#'     values = "square")
 #'
 #' # Get the articulation points in the graph (i.e.,
 #' # those nodes that if any were to be removed, the
 #' # graph would become disconnected)
 #' get_articulation_points(graph)
-#' #> [1]  8 22 24
+#' #> [1]  9 10 12 19 22 26 30
 #'
 #' # For the articulation points, change the node
-#' # shape to a circle
+#' # shape to a `circle`
 #' graph <-
 #'   graph %>%
 #'   select_nodes_by_id(
-#'     get_articulation_points(.)) %>%
-#'   set_node_attrs_ws("shape", "circle")
+#'     nodes = get_articulation_points(.)) %>%
+#'   set_node_attrs_ws(
+#'     node_attr = "shape",
+#'     value = "circle")
 #' @importFrom igraph articulation_points as_ids
 #' @export get_articulation_points
 
@@ -44,5 +50,5 @@ get_articulation_points <- function(graph) {
   articulation_points <-
     igraph::as_ids(articulation_points)
 
-  return(sort(as.integer(articulation_points)))
+  sort(as.integer(articulation_points))
 }
