@@ -71,14 +71,14 @@
 #' # attribute greater than 3)
 #' get_edges(
 #'   graph,
-#'   conditions = "value > 3",
+#'   conditions = value > 3,
 #'   return_type = "vector")
 #' #> [1] "1->4" "3->1"
 #'
 #' # Get a vector of edges using a match
 #' get_edges(
 #'   graph,
-#'   conditions = "color == 'pink'",
+#'   conditions = color == "pink",
 #'   return_type = "vector")
 #' #> [1] "1->4"
 #'
@@ -86,8 +86,9 @@
 #' # with the desired attribute values
 #' get_edges(
 #'   graph,
-#'   conditions = c("color == 'blue'",
-#'                  "value > 3"),
+#'   conditions =
+#'     color == "blue" &
+#'     value > 3,
 #'   return_type = "vector")
 #' #> [1] "3->1"
 #'
@@ -95,12 +96,14 @@
 #' # the labels of the connected nodes
 #' get_edges(
 #'   graph,
-#'   conditions = c("color == 'blue'",
-#'                  "value > 3"),
+#'   conditions =
+#'     color == "blue" &
+#'     value > 3,
 #'   return_type = "vector",
 #'   return_values = "label")
 #' #> [1] "three->one"
-#' @importFrom dplyr filter_ select_ left_join rename
+#' @importFrom dplyr filter select_ left_join rename
+#' @importFrom rlang enquo UQ
 #' @export get_edges
 
 get_edges <- function(x,
@@ -108,6 +111,8 @@ get_edges <- function(x,
                       return_type = "vector",
                       return_values = "id") {
 
+  conditions <- rlang::enquo(conditions)
+
   # Create bindings for specific variables
   label <- NULL
 
@@ -138,12 +143,12 @@ get_edges <- function(x,
   # If conditions are provided then
   # pass in those conditions and filter the
   # data frame of `edges_df`
-  if (!is.null(conditions)) {
-    for (i in 1:length(conditions)) {
-      edges_df <-
-        edges_df %>%
-        dplyr::filter_(conditions[i])
-    }
+  if (!((rlang::UQ(conditions) %>% paste())[2] == "NULL")) {
+
+    edges_df <-
+      filter(
+        .data = edges_df,
+        rlang::UQ(conditions))
   }
 
   # If no edges remain then return NA
