@@ -11,7 +11,10 @@
 #' graph <- create_graph()
 #'
 #' # Provide the new graph with a name
-#' graph <- set_graph_name(graph, "the_name")
+#' graph <-
+#'   set_graph_name(
+#'     graph,
+#'     name = "the_name")
 #'
 #' # Get the graph's name
 #' get_graph_name(graph)
@@ -25,5 +28,5 @@ get_graph_name <- function(graph) {
     stop("The graph object is not valid.")
   }
 
-  return(graph$graph_info$graph_name)
+  graph$graph_info$graph_name
 }
