@@ -4,7 +4,7 @@
 #' @param graph a graph object of class
 #' \code{dgr_graph}.
 #' @param conditions an option to use filtering
-#' conditions for the retrieval of nodes.
+#' conditions for the retrieval of edges.
 #' @param set_op the set operation to perform upon
 #' consecutive selections of graph nodes. This can
 #' either be as a \code{union} (the default), as an
@@ -45,7 +45,8 @@
 #' graph <-
 #'   graph %>%
 #'   select_edges(
-#'     from = 1, to = 4)
+#'     from = 1,
+#'     to = 4)
 #'
 #' # Verify that an edge selection has been made
 #' # using the `get_selection()` function
@@ -58,7 +59,7 @@
 #'   graph %>%
 #'   clear_selection() %>%
 #'   select_edges(
-#'     conditions = "rel == 'z'")
+#'     conditions = rel == "z")
 #'
 #' # Verify that an edge selection has been made, and
 #' # recall that the `2`->`3` edge uniquely has the
@@ -73,14 +74,15 @@
 #'   graph %>%
 #'   clear_selection() %>%
 #'   select_edges(
-#'     conditions = "value > 3.0")
+#'     conditions = value > 3.0)
 #'
 #' # Verify that the correct edge selection has been
 #' # made; in this case, edges `1`->`4` and
 #' # `3`->`1` have values for `value` > 3.0
 #' get_selection(graph)
 #' #> [1] 1 3
-#' @importFrom dplyr filter_ filter select rename
+#' @importFrom dplyr filter select rename
+#' @importFrom rlang enquo UQ
 #' @export select_edges
 
 select_edges <- function(graph,
@@ -89,6 +91,8 @@ select_edges <- function(graph,
                          from = NULL,
                          to = NULL) {
 
+  conditions <- rlang::enquo(conditions)
+
   # Get the time of function start
   time_function_start <- Sys.time()
 
@@ -116,12 +120,12 @@ select_edges <- function(graph,
   # If conditions are provided then
   # pass in those conditions and filter the
   # data frame of `edges_df`
-  if (!is.null(conditions)) {
-    for (i in 1:length(conditions)) {
-      edges_df <-
-        edges_df %>%
-        dplyr::filter_(conditions[i])
-    }
+  if (!((rlang::UQ(conditions) %>% paste())[2] == "NULL")) {
+
+    edges_df <-
+      filter(
+        .data = edges_df,
+        rlang::UQ(conditions))
   }
 
   # If a `from` vector provided, filter the edf
@@ -210,5 +214,5 @@ select_edges <- function(graph,
     save_graph_as_rds(graph = graph)
   }
 
-  return(graph)
+  graph
 }
