@@ -18,16 +18,18 @@
 #' # Create a graph with 5 nodes
 #' graph <-
 #'   create_graph() %>%
-#'   add_path(5)
+#'   add_path(n = 5)
 #'
 #' # Create a graph selection by selecting edges
 #' # associated with nodes `1` and `2`
 #' graph <-
 #'   graph %>%
-#'   select_edges_by_node_id(1:2)
+#'   select_edges_by_node_id(
+#'     nodes = 1:2)
 #'
 #' # Get the selection of edges
-#' graph %>% get_selection()
+#' graph %>%
+#'   get_selection()
 #' #> [1] 1 2
 #'
 #' # Perform another selection of edges, with nodes
@@ -35,10 +37,12 @@
 #' graph <-
 #'   graph %>%
 #'   clear_selection() %>%
-#'   select_edges_by_node_id(c(1, 2, 4))
+#'   select_edges_by_node_id(
+#'     nodes = c(1, 2, 4))
 #'
 #' # Get the selection of edges
-#' graph %>% get_selection
+#' graph %>%
+#'   get_selection()
 #' #> [1] 1 2 3 4
 #'
 #' # Get a fraction of the edges selected over all
@@ -136,5 +140,5 @@ select_edges_by_node_id <- function(graph,
     save_graph_as_rds(graph = graph)
   }
 
-  return(graph)
+  graph
 }
