@@ -9,27 +9,37 @@
 #' # Create three graphs
 #' graph_1 <-
 #'   create_graph() %>%
-#'   add_n_nodes(3) %>%
+#'   add_n_nodes(n = 3) %>%
 #'   add_edges_w_string(
-#'     "1->3 1->2 2->3")
+#'     edges = "1->3 1->2 2->3")
 #'
 #' graph_2 <-
 #'   graph_1 %>%
-#'   add_node %>%
-#'   add_edge(4, 3)
+#'   add_node() %>%
+#'   add_edge(
+#'     from = 4,
+#'     to = 3)
 #'
 #' graph_3 <-
 #'   graph_2 %>%
-#'   add_node %>%
-#'   add_edge(5, 2)
+#'   add_node() %>%
+#'   add_edge(
+#'     from = 5,
+#'     to = 2)
 #'
 #' # Create an empty graph series and add
 #' # the graphs
 #' series <-
 #'   create_series() %>%
-#'   add_to_series(graph_1, .) %>%
-#'   add_to_series(graph_2, .) %>%
-#'   add_to_series(graph_3, .)
+#'   add_to_series(
+#'     graph_1,
+#'     graph_series = .) %>%
+#'   add_to_series(
+#'     graph_2,
+#'     graph_series = .) %>%
+#'   add_to_series(
+#'     graph_3,
+#'     graph_series = .)
 #'
 #' # Get information on the graphs in the series
 #' series_info(series)
@@ -92,5 +102,5 @@ series_info <- function(graph_series) {
       is_graph_directed(graph_series$graphs[[i]])
   }
 
-  return(series_info_df)
+  series_info_df
 }
