@@ -8,62 +8,90 @@ test_that("Adding a balanced tree is possible", {
   # Add a balanced tree
   graph <-
     add_balanced_tree(
-      graph, k = 3, h = 3, type = "a", rel = "z")
+      graph = graph,
+      k = 3,
+      h = 3,
+      type = "a",
+      rel = "z")
 
   # Expect 40 nodes to have been created
-  expect_equal(node_count(graph), 40)
+  expect_equal(
+    node_count(graph), 40)
 
   # Expect 39 edges to have been created
-  expect_equal(edge_count(graph), 39)
+  expect_equal(
+    edge_count(graph), 39)
 
   # Expect node ID values from 1 to 40
-  expect_identical(get_node_ids(graph), 1:40)
+  expect_identical(
+    get_node_ids(graph), 1:40)
 
   # Expect label values from 1 to 40
-  expect_identical(graph$nodes_df$label,
-                   as.character(1:40))
+  expect_identical(
+    graph$nodes_df$label,
+    as.character(1:40))
 
   # Expect type values to all be `a`
-  expect_equal(unique(graph$nodes_df$type), "a")
+  expect_equal(
+    unique(graph$nodes_df$type), "a")
 
   # Expect rel values to all be `z`
-  expect_equal(unique(graph$edges_df$rel), "z")
+  expect_equal(
+    unique(graph$edges_df$rel), "z")
 
   # Expect an error if k is <2
   expect_error(
     add_balanced_tree(
-      graph, k = 1, h = 3, type = "a", rel = "z"))
+      graph = graph,
+      k = 1,
+      h = 3,
+      type = "a",
+      rel = "z"))
 
   # Expect an error if h is <2
   expect_error(
     add_balanced_tree(
-      graph, k = 3, h = 1, type = "a", rel = "z"))
+      graph = graph,
+      k = 3,
+      h = 1,
+      type = "a",
+      rel = "z"))
 
-  # Add another balanced tree
+  # Add another balanced tree to the graph
   graph <-
     add_balanced_tree(
-      graph, k = 2, h = 2, type = "b", rel = "y")
+      graph = graph,
+      k = 2,
+      h = 2,
+      type = "b",
+      rel = "y")
 
   # Expect that 47 nodes are now in the graph
-  expect_equal(node_count(graph), 47)
+  expect_equal(
+    node_count(graph), 47)
 
   # Expect 45 edges are now in the graph
-  expect_equal(edge_count(graph), 45)
+  expect_equal(
+    edge_count(graph), 45)
 
   # Expect node ID values from 1 to 47
-  expect_identical(get_node_ids(graph), 1:47)
+  expect_identical(
+    get_node_ids(graph), 1:47)
 
   # Expect label values from 1 to 47
-  expect_equal(graph$nodes_df$label,
-               as.character(1:47))
+  expect_equal(
+    graph$nodes_df$label,
+    as.character(1:47))
 
   # Expect type values to be either `a` or `b`
-  expect_identical(unique(graph$nodes_df$type),
-                   c("a", "b"))
+  expect_identical(
+    unique(graph$nodes_df$type),
+    c("a", "b"))
 
   # Expect rel values to be either `a` or `b`
-  expect_identical(unique(graph$edges_df$rel),
-                   c("z", "y"))
+  expect_identical(
+    unique(graph$edges_df$rel),
+    c("z", "y"))
 })
 
 test_that("Adding a cycle is possible", {
@@ -73,55 +101,142 @@ test_that("Adding a cycle is possible", {
 
   # Add a cycle
   graph <-
-    add_cycle(graph, n = 3, type = "a", rel = "z")
+    add_cycle(
+      graph = graph,
+      n = 3,
+      type = "a",
+      rel = "z")
 
   # Expect 3 nodes to have been created
-  expect_equal(node_count(graph), 3)
+  expect_equal(
+    node_count(graph), 3)
 
   # Expect 3 edges to have been created
-  expect_equal(edge_count(graph), 3)
+  expect_equal(
+    edge_count(graph), 3)
 
   # Expect node ID values from 1 to 3
-  expect_identical(get_node_ids(graph), 1:3)
+  expect_identical(
+    get_node_ids(graph), 1:3)
 
   # Expect label values from 1 to 3
-  expect_identical(graph$nodes_df$label,
-                   as.character(1:3))
+  expect_identical(
+    graph$nodes_df$label,
+    as.character(1:3))
 
   # Expect type values to all be `a`
-  expect_equal(unique(graph$nodes_df$type), "a")
+  expect_equal(
+    unique(graph$nodes_df$type), "a")
 
   # Expect rel values to all be `z`
-  expect_equal(unique(graph$edges_df$rel), "z")
+  expect_equal(
+    unique(graph$edges_df$rel), "z")
 
   # Expect an error if n is <3
   expect_error(
-    add_cycle(graph, n = 2, type = "a", rel = "z"))
+    add_cycle(
+      graph = graph,
+      n = 2,
+      type = "a",
+      rel = "z"))
 
-  # Add another cycle
+  # Add another cycle to the graph
   graph <-
-    add_cycle(graph, n = 3, type = "b", rel = "y")
+    add_cycle(
+      graph = graph,
+      n = 3,
+      type = "b",
+      rel = "y")
 
   # Expect that 6 nodes are now in the graph
-  expect_equal(node_count(graph), 6)
+  expect_equal(
+    node_count(graph), 6)
 
   # Expect 6 edges are now in the graph
-  expect_equal(edge_count(graph), 6)
+  expect_equal(
+    edge_count(graph), 6)
 
   # Expect node ID values from 1 to 6
-  expect_identical(get_node_ids(graph), 1:6)
+  expect_identical(
+    get_node_ids(graph), 1:6)
 
   # Expect label values from 1 to 6
-  expect_identical(graph$nodes_df$label,
-                   as.character(1:6))
+  expect_identical(
+    graph$nodes_df$label,
+    as.character(1:6))
 
   # Expect type values to be either `a` or `b`
-  expect_identical(unique(graph$nodes_df$type),
-                   c("a", "b"))
+  expect_identical(
+    unique(graph$nodes_df$type),
+    c("a", "b"))
 
   # Expect rel values to be either `a` or `b`
-  expect_identical(unique(graph$edges_df$rel),
-                   c("z", "y"))
+  expect_identical(
+    unique(graph$edges_df$rel),
+    c("z", "y"))
+
+  # Create a graph with a cycle that
+  # has different types of node and edge
+  # attributes included
+  graph_2 <-
+    create_graph() %>%
+    add_cycle(
+      n = 6,
+      label = c("one", "two",
+                "three", "four",
+                "five", "six"),
+      type = c("a", "a",
+               "b", "b",
+               "c", "c"),
+      value = c(1.2, 8.4,
+                3.4, 5.2,
+                6.1, 2.6),
+      rel = c("cycle_a", "cycle_a",
+              "cycle_b", "cycle_b",
+              "cycle_c", "cycle_c"))
+
+  # Get the graph's node data frame
+  ndf <- get_node_df(graph_2)
+
+  # Get the graph's edge data frame
+  edf <- get_edge_df(graph_2)
+
+  # Expect that 6 nodes are now in the graph
+  expect_equal(
+    node_count(graph_2), 6)
+
+  # Expect 6 edges are now in the graph
+  expect_equal(
+    edge_count(graph_2), 6)
+
+  # Expect node ID values from 1 to 6
+  expect_identical(
+    ndf$id, 1:6)
+
+  # Expect specific node `label` values
+  expect_identical(
+    ndf$label,
+    c("one", "two",
+      "three", "four",
+      "five", "six"))
+
+  # Expect specific node `type` values
+  expect_identical(
+    ndf$type,
+    c("a", "a", "b",
+      "b", "c", "c"))
+
+  # Expect specific node `value` values
+  expect_identical(
+    ndf$value,
+    c(1.2, 8.4, 3.4, 5.2, 6.1, 2.6))
+
+  # Expect specific edge `rel` values
+  expect_identical(
+    edf$rel,
+    c("cycle_a", "cycle_a",
+      "cycle_b", "cycle_b",
+      "cycle_c", "cycle_c"))
 })
 
 test_that("Adding a path is possible", {
@@ -131,55 +246,142 @@ test_that("Adding a path is possible", {
 
   # Add a path
   graph <-
-    add_path(graph, n = 3, type = "a", rel = "z")
+    add_path(
+      graph = graph,
+      n = 3,
+      type = "a",
+      rel = "z")
 
   # Expect 3 nodes to have been created
-  expect_equal(node_count(graph), 3)
+  expect_equal(
+    node_count(graph), 3)
 
   # Expect 2 edges to have been created
-  expect_equal(edge_count(graph), 2)
+  expect_equal(
+    edge_count(graph), 2)
 
   # Expect node ID values from 1 to 3
-  expect_identical(get_node_ids(graph), 1:3)
+  expect_identical(
+    get_node_ids(graph), 1:3)
 
   # Expect label values from 1 to 3
-  expect_identical(graph$nodes_df$label,
-                   as.character(1:3))
+  expect_identical(
+    graph$nodes_df$label,
+    as.character(1:3))
 
   # Expect type values to all be `a`
-  expect_equal(unique(graph$nodes_df$type), "a")
+  expect_equal(
+    unique(graph$nodes_df$type), "a")
 
   # Expect rel values to all be `z`
-  expect_equal(unique(graph$edges_df$rel), "z")
+  expect_equal(
+    unique(graph$edges_df$rel), "z")
 
   # Expect an error if n is <2
   expect_error(
-    add_path(graph, n = 1, type = "a", rel = "z"))
+    add_path(
+      graph = graph,
+      n = 1,
+      type = "a",
+      rel = "z"))
 
-  # Add another path
+  # Add another path to the graph
   graph <-
-    add_path(graph, n = 3, type = "b", rel = "y")
+    add_path(
+      graph = graph,
+      n = 3,
+      type = "b",
+      rel = "y")
 
   # Expect that 6 nodes are now in the graph
-  expect_equal(node_count(graph), 6)
+  expect_equal(
+    node_count(graph), 6)
 
-  # Expect 4 edges are now in the graph
-  expect_equal(edge_count(graph), 4)
+  # Expect 6 edges are now in the graph
+  expect_equal(
+    edge_count(graph), 4)
 
   # Expect node ID values from 1 to 6
-  expect_identical(get_node_ids(graph), 1:6)
+  expect_identical(
+    get_node_ids(graph), 1:6)
 
   # Expect label values from 1 to 6
-  expect_identical(graph$nodes_df$label,
-                   as.character(1:6))
+  expect_identical(
+    graph$nodes_df$label,
+    as.character(1:6))
 
   # Expect type values to be either `a` or `b`
-  expect_identical(unique(graph$nodes_df$type),
-                   c("a", "b"))
+  expect_identical(
+    unique(graph$nodes_df$type),
+    c("a", "b"))
 
   # Expect rel values to be either `a` or `b`
-  expect_identical(unique(graph$edges_df$rel),
-                   c("z", "y"))
+  expect_identical(
+    unique(graph$edges_df$rel),
+    c("z", "y"))
+
+  # Create a graph with a path that
+  # has different types of node and edge
+  # attributes included
+  graph_2 <-
+    create_graph() %>%
+    add_path(
+      n = 6,
+      label = c("one", "two",
+                "three", "four",
+                "five", "six"),
+      type = c("a", "a",
+               "a", "b",
+               "b", "b"),
+      value = c(1.2, 8.4,
+                3.4, 5.2,
+                6.1, 2.6),
+      rel = c("path_a", "path_b",
+              "path_c", "path_d",
+              "path_e"))
+
+  # Get the graph's node data frame
+  ndf <- get_node_df(graph_2)
+
+  # Get the graph's edge data frame
+  edf <- get_edge_df(graph_2)
+
+  # Expect that 6 nodes are now in the graph
+  expect_equal(
+    node_count(graph_2), 6)
+
+  # Expect 5 edges are now in the graph
+  expect_equal(
+    edge_count(graph_2), 5)
+
+  # Expect node ID values from 1 to 6
+  expect_identical(
+    ndf$id, 1:6)
+
+  # Expect specific node `label` values
+  expect_identical(
+    ndf$label,
+    c("one", "two",
+      "three", "four",
+      "five", "six"))
+
+  # Expect specific node `type` values
+  expect_identical(
+    ndf$type,
+    c("a", "a", "a",
+      "b", "b", "b"))
+
+  # Expect specific node `value` values
+  expect_identical(
+    ndf$value,
+    c(1.2, 8.4, 3.4, 5.2, 6.1, 2.6))
+
+  # Expect specific edge `rel` values
+  expect_identical(
+    edf$rel,
+    c("path_a", "path_b",
+      "path_c", "path_d",
+      "path_e"))
 })
 
 test_that("Adding a prism is possible", {
@@ -189,52 +391,142 @@ test_that("Adding a prism is possible", {
 
   # Add a prism
   graph <-
-    add_prism(graph, n = 3, type = "a", rel = "z")
+    add_prism(
+      graph = graph,
+      n = 3,
+      type = "a",
+      rel = "z")
 
   # Expect 6 nodes to have been created
-  expect_equal(node_count(graph), 6)
+  expect_equal(
+    node_count(graph), 6)
 
   # Expect 9 edges to have been created
-  expect_equal(edge_count(graph), 9)
+  expect_equal(
+    edge_count(graph), 9)
 
   # Expect node ID values from 1 to 6
-  expect_identical(get_node_ids(graph), 1:6)
+  expect_identical(
+    get_node_ids(graph), 1:6)
 
   # Expect label values from 1 to 6
-  expect_identical(graph$nodes_df$label,
-                   as.character(1:6))
+  expect_identical(
+    graph$nodes_df$label,
+    as.character(1:6))
 
   # Expect type values to all be `a`
-  expect_equal(unique(graph$nodes_df$type), "a")
+  expect_equal(
+    unique(graph$nodes_df$type), "a")
 
   # Expect rel values to all be `z`
-  expect_equal(unique(graph$edges_df$rel), "z")
+  expect_equal(
+    unique(graph$edges_df$rel), "z")
 
   # Expect an error if n is <3
   expect_error(
-    add_prism(graph, n = 2, type = "a", rel = "z"))
+    add_prism(
+      graph = graph,
+      n = 2,
+      type = "a",
+      rel = "z"))
 
-  # Add another prism
+  # Add another prism to the graph
   graph <-
-    add_prism(graph, n = 3, type = "b", rel = "y")
+    add_prism(
+      graph = graph,
+      n = 3,
+      type = "b",
+      rel = "y")
 
   # Expect that 12 nodes are now in the graph
-  expect_equal(node_count(graph), 12)
+  expect_equal(
+    node_count(graph), 12)
 
   # Expect 18 edges are now in the graph
-  expect_equal(edge_count(graph), 18)
+  expect_equal(
+    edge_count(graph), 18)
 
   # Expect label values from 1 to 12
-  expect_identical(graph$nodes_df$label,
-                   as.character(1:12))
+  expect_identical(
+    graph$nodes_df$label,
+    as.character(1:12))
 
   # Expect type values to be either `a` or `b`
-  expect_identical(unique(graph$nodes_df$type),
-                   c("a", "b"))
+  expect_identical(
+    unique(graph$nodes_df$type),
+    c("a", "b"))
 
   # Expect rel values to be either `a` or `b`
-  expect_identical(unique(graph$edges_df$rel),
-                   c("z", "y"))
+  expect_identical(
+    unique(graph$edges_df$rel),
+    c("z", "y"))
+
+  # Create a graph with a prism that
+  # has different types of node and edge
+  # attributes included
+  graph_2 <-
+    create_graph() %>%
+    add_prism(
+      n = 3,
+      label = c("one", "two",
+                "three", "four",
+                "five", "six"),
+      type = c("a", "a",
+               "a", "b",
+               "b", "b"),
+      value = c(1.2, 8.4,
+                3.4, 5.2,
+                6.1, 2.6),
+      rel = c("prism_a", "prism_a",
+              "prism_a", "prism_b",
+              "prism_b", "prism_b",
+              "prism_c", "prism_c",
+              "prism_c"))
+
+  # Get the graph's node data frame
+  ndf <- get_node_df(graph_2)
+
+  # Get the graph's edge data frame
+  edf <- get_edge_df(graph_2)
+
+  # Expect that 6 nodes are now in the graph
+  expect_equal(
+    node_count(graph_2), 6)
+
+  # Expect 9 edges are now in the graph
+  expect_equal(
+    edge_count(graph_2), 9)
+
+  # Expect node ID values from 1 to 6
+  expect_identical(
+    ndf$id, 1:6)
+
+  # Expect specific node `label` values
+  expect_identical(
+    ndf$label,
+    c("one", "two",
+      "three", "four",
+      "five", "six"))
+
+  # Expect specific node `type` values
+  expect_identical(
+    ndf$type,
+    c("a", "a", "a",
+      "b", "b", "b"))
+
+  # Expect specific node `value` values
+  expect_identical(
+    ndf$value,
+    c(1.2, 8.4, 3.4, 5.2, 6.1, 2.6))
+
+  # Expect specific edge `rel` values
+  expect_identical(
+    edf$rel,
+    c("prism_a", "prism_a",
+      "prism_a", "prism_b",
+      "prism_b", "prism_b",
+      "prism_c", "prism_c",
+      "prism_c"))
 })
 
 test_that("Adding a star is possible", {
@@ -244,55 +536,142 @@ test_that("Adding a star is possible", {
 
   # Add a star
   graph <-
-    add_star(graph, n = 4, type = "a", rel = "z")
+    add_star(
+      graph = graph,
+      n = 4,
+      type = "a",
+      rel = "z")
 
   # Expect 4 nodes to have been created
-  expect_equal(node_count(graph), 4)
+  expect_equal(
+    node_count(graph), 4)
 
   # Expect 3 edges to have been created
-  expect_equal(edge_count(graph), 3)
+  expect_equal(
+    edge_count(graph), 3)
 
   # Expect node ID values from 1 to 4
-  expect_identical(get_node_ids(graph), 1:4)
+  expect_identical(
+    get_node_ids(graph), 1:4)
 
   # Expect label values from 1 to 4
-  expect_identical(graph$nodes_df$label,
-                   as.character(1:4))
+  expect_identical(
+    graph$nodes_df$label,
+    as.character(1:4))
 
   # Expect type values to all be `a`
-  expect_equal(unique(graph$nodes_df$type), "a")
+  expect_equal(
+    unique(graph$nodes_df$type), "a")
 
   # Expect rel values to all be `z`
-  expect_equal(unique(graph$edges_df$rel), "z")
+  expect_equal(
+    unique(graph$edges_df$rel), "z")
 
   # Expect an error if n is <4
   expect_error(
-    add_star(graph, n = 3, type = "a", rel = "z"))
+    add_star(
+      graph = graph,
+      n = 3,
+      type = "a",
+      rel = "z"))
 
-  # Add another star
+  # Add another star to the graph
   graph <-
-    add_star(graph, n = 4, type = "b", rel = "y")
+    add_star(
+      graph = graph,
+      n = 4,
+      type = "b",
+      rel = "y")
 
   # Expect that 8 nodes are now in the graph
-  expect_equal(node_count(graph), 8)
+  expect_equal(
+    node_count(graph), 8)
 
   # Expect 6 edges are now in the graph
-  expect_equal(edge_count(graph), 6)
+  expect_equal(
+    edge_count(graph), 6)
 
   # Expect node ID values from 1 to 8
-  expect_identical(get_node_ids(graph), 1:8)
+  expect_identical(
+    get_node_ids(graph), 1:8)
 
   # Expect label values from 1 to 8
-  expect_identical(graph$nodes_df$label,
-                   as.character(1:8))
+  expect_identical(
+    graph$nodes_df$label,
+    as.character(1:8))
 
   # Expect type values to be either `a` or `b`
-  expect_identical(unique(graph$nodes_df$type),
-                   c("a", "b"))
+  expect_identical(
+    unique(graph$nodes_df$type),
+    c("a", "b"))
 
-  # Expect rel values to be either `a` or `b`
-  expect_identical(unique(graph$edges_df$rel),
-                   c("z", "y"))
+  # Expect rel values to be either `z` or `y`
+  expect_identical(
+    unique(graph$edges_df$rel),
+    c("z", "y"))
+
+  # Create a graph with a star that
+  # has different types of node and edge
+  # attributes included
+  graph_2 <-
+    create_graph() %>%
+    add_star(
+      n = 6,
+      label = c("one", "two",
+                "three", "four",
+                "five", "six"),
+      type = c("a", "a",
+               "b", "b",
+               "c", "c"),
+      value = c(1.2, 8.4,
+                3.4, 5.2,
+                6.1, 2.6),
+      rel = c("star_a", "star_b",
+              "star_c", "star_d",
+              "star_e"))
+
+  # Get the graph's node data frame
+  ndf <- get_node_df(graph_2)
+
+  # Get the graph's edge data frame
+  edf <- get_edge_df(graph_2)
+
+  # Expect that 6 nodes are now in the graph
+  expect_equal(
+    node_count(graph_2), 6)
+
+  # Expect 5 edges are now in the graph
+  expect_equal(
+    edge_count(graph_2), 5)
+
+  # Expect node ID values from 1 to 6
+  expect_identical(
+    ndf$id, 1:6)
+
+  # Expect specific node `label` values
+  expect_identical(
+    ndf$label,
+    c("one", "two",
+      "three", "four",
+      "five", "six"))
+
+  # Expect specific node `type` values
+  expect_identical(
+    ndf$type,
+    c("a", "a", "b",
+      "b", "c", "c"))
+
+  # Expect specific node `value` values
+  expect_identical(
+    ndf$value,
+    c(1.2, 8.4, 3.4, 5.2, 6.1, 2.6))
+
+  # Expect specific edge `rel` values
+  expect_identical(
+    edf$rel,
+    c("star_a", "star_b",
+      "star_c", "star_d",
+      "star_e"))
 })
 
 test_that("Adding a full graph is possible", {
@@ -302,13 +681,16 @@ test_that("Adding a full graph is possible", {
   graph <-
     create_graph() %>%
     add_full_graph(
-      n = 3, keep_loops = TRUE)
+      n = 3,
+      keep_loops = TRUE)
 
   # Expect 3 nodes to have been created
-  expect_equal(node_count(graph), 3)
+  expect_equal(
+    node_count(graph), 3)
 
   # Expect 9 edges to have been created
-  expect_equal(edge_count(graph), 9)
+  expect_equal(
+    edge_count(graph), 9)
 
   # Expect that there are 3 loops in the graph
   expect_equal(
@@ -318,24 +700,29 @@ test_that("Adding a full graph is possible", {
           graph$edges_df$to)), 3)
 
   # Expect node ID values from 1 to 3
-  expect_identical(get_node_ids(graph), 1:3)
+  expect_identical(
+    get_node_ids(graph), 1:3)
 
   # Expect type values to be character NA values
-  expect_equal(unique(graph$nodes_df$type),
-               as.character(NA))
+  expect_equal(
+    unique(graph$nodes_df$type),
+    as.character(NA))
 
   # Create a graph and add a full graph
   # with 3 nodes to it; discard loops
   graph <-
     create_graph() %>%
     add_full_graph(
-      n = 3, keep_loops = FALSE)
+      n = 3,
+      keep_loops = FALSE)
 
   # Expect 3 nodes to have been created
-  expect_equal(node_count(graph), 3)
+  expect_equal(
+    node_count(graph), 3)
 
   # Expect 6 edges to have been created
-  expect_equal(edge_count(graph), 6)
+  expect_equal(
+    edge_count(graph), 6)
 
   # Expect that there are no loops in the graph
   expect_equal(
@@ -356,10 +743,12 @@ test_that("Adding a full graph is possible", {
       rel = "connected_to")
 
   # Expect 3 nodes to have been created
-  expect_equal(node_count(graph), 3)
+  expect_equal(
+    node_count(graph), 3)
 
   # Expect 6 edges to have been created
-  expect_equal(edge_count(graph), 6)
+  expect_equal(
+    edge_count(graph), 6)
 
   # Expect that there are no loops in the graph
   expect_equal(
@@ -398,11 +787,12 @@ test_that("Adding a full graph is possible", {
   set.seed(23)
 
   edge_wt_matrix_rownames <-
-    rnorm(100, 5, 2) %>%
-    sample(9, FALSE) %>%
-    round(2) %>%
+    rnorm(n = 100, mean = 5, sd = 2) %>%
+    sample(size = 9, replace = FALSE) %>%
+    round(digits = 2) %>%
     matrix(
-      nc = 3, nr = 3,
+      ncol = 3,
+      nrow = 3,
       dimnames = list(c("a", "b", "c")))
 
   # Create a fully-connected graph without
@@ -419,10 +809,12 @@ test_that("Adding a full graph is possible", {
       keep_loops = FALSE)
 
   # Expect 3 nodes to have been created
-  expect_equal(node_count(graph), 3)
+  expect_equal(
+    node_count(graph), 3)
 
   # Expect 6 edges to have been created
-  expect_equal(edge_count(graph), 6)
+  expect_equal(
+    edge_count(graph), 6)
 
   # Expect that there are no loops in the graph
   expect_equal(
@@ -475,10 +867,12 @@ test_that("Adding a full graph is possible", {
       keep_loops = FALSE)
 
   # Expect 3 nodes to have been created
-  expect_equal(node_count(graph), 3)
+  expect_equal(
+    node_count(graph), 3)
 
   # Expect 3 edges to have been created
-  expect_equal(edge_count(graph), 3)
+  expect_equal(
+    edge_count(graph), 3)
 
   # Expect that there are no loops in the graph
   expect_equal(
@@ -529,10 +923,12 @@ test_that("Adding a full graph is possible", {
       keep_loops = TRUE)
 
   # Expect 3 nodes to have been created
-  expect_equal(node_count(graph), 3)
+  expect_equal(
+    node_count(graph), 3)
 
   # Expect 9 edges to have been created
-  expect_equal(edge_count(graph), 9)
+  expect_equal(
+    edge_count(graph), 9)
 
   # Expect that there are 3 loops in the graph
   expect_equal(
@@ -584,10 +980,12 @@ test_that("Adding a full graph is possible", {
       keep_loops = TRUE)
 
   # Expect 3 nodes to have been created
-  expect_equal(node_count(graph), 3)
+  expect_equal(
+    node_count(graph), 3)
 
   # Expect 6 edges to have been created
-  expect_equal(edge_count(graph), 6)
+  expect_equal(
+    edge_count(graph), 6)
 
   # Expect that there are 3 loops in the graph
   expect_equal(
@@ -639,10 +1037,12 @@ test_that("Adding a full graph is possible", {
       keep_loops = TRUE)
 
   # Expect 3 nodes to have been created
-  expect_equal(node_count(graph), 3)
+  expect_equal(
+    node_count(graph), 3)
 
   # Expect 6 edges to have been created
-  expect_equal(edge_count(graph), 6)
+  expect_equal(
+    edge_count(graph), 6)
 
   # Expect that there are 3 loops in the graph
   expect_equal(
@@ -682,13 +1082,18 @@ test_that("Adding a full graph is possible", {
   # with 3 nodes to it; discard loops
   graph <-
     create_graph() %>%
-    add_cycle(5, "cycle") %>%
+    add_cycle(
+      n = 5,
+      type = "cycle") %>%
     add_full_graph(
-      n = 8, keep_loops = FALSE)
+      n = 8,
+      keep_loops = FALSE)
 
   # Expect 13 nodes to have been created
-  expect_equal(node_count(graph), 13)
+  expect_equal(
+    node_count(graph), 13)
 
   # Expect 6 edges to have been created
-  expect_equal(edge_count(graph), 61)
+  expect_equal(
+    edge_count(graph), 61)
 })
