@@ -28,25 +28,28 @@ test_that("a subgraph can be created and such an object is correct", {
   # graph object
   graph_ns <-
     graph %>%
-    select_nodes("value > 3")
+    select_nodes(conditions = value > 3)
 
   # Create a subgraph based on the selection
   subgraph_ns <- create_subgraph_ws(graph_ns)
 
   # Expect that only those nodes with a value >3 are in the subgraph
   expect_true(
-    all(c(1, 3, 5, 7, 8) %in% get_node_ids(subgraph_ns)))
+    all(
+      c(1, 3, 5, 7, 8) %in% get_node_ids(subgraph_ns)))
 
   # Expect only certain edges to be present in the subgraph
   expect_true(
-    all(c("3->1", "7->3", "5->8") %in%
-          get_edges(subgraph_ns, return_type = "vector")))
+    all(
+      c("3->1", "7->3", "5->8") %in% get_edges(
+        x = subgraph_ns,
+        return_type = "vector")))
 
   # Create a selection of edges, stored within the
   # graph object
   graph_es <-
     graph %>%
-    select_edges("value > 4")
+    select_edges(conditions = value > 4)
 
   # Create a subgraph based on the selection
   subgraph_es <- create_subgraph_ws(graph_es)
@@ -57,11 +60,15 @@ test_that("a subgraph can be created and such an object is correct", {
 
   # Expect only certain edges to be present in the subgraph
   expect_true(
-    all(c("7->3", "8->4", "6->5", "3->4") %in%
-          get_edges(subgraph_es, return_type = "vector")))
+    all(
+      c("7->3", "8->4", "6->5", "3->4") %in% get_edges(
+        x = subgraph_es,
+        return_type = "vector")))
 
   # Expect an error when attempting to create a subgraph with
   # a graph without an active selection
   graph <- clear_selection(graph)
-  expect_error(create_subgraph_ws(graph))
+
+  expect_error(
+    create_subgraph_ws(graph))
 })
